summaryrefslogtreecommitdiff
path: root/TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h')
-rw-r--r--TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h b/TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h
index c95dfde5e00..e6d1f8c7be0 100644
--- a/TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h
+++ b/TAO/tao/RTPortableServer/RT_Servant_Dispatcher.h
@@ -76,7 +76,8 @@ class TAO_RTPortableServer_Export RT_Priority_Model_Processing
public:
// Constructor.
- RT_Priority_Model_Processing (TAO_POA &poa);
+ RT_Priority_Model_Processing (TAO_POA &poa,
+ CORBA::Short servant_priority);
// Resets the priority of the current thread back to its original
// value if necessary, i.e., if it was changed and the
@@ -114,11 +115,11 @@ private:
// Poa of the target servant.
TAO_POA &poa_;
- // Original native priority of the thread.
- RTCORBA::Priority original_native_priority_;
+ // Servant Priority.
+ CORBA::Short servant_priority_;
- // Original CORBA priority of the thread.
- RTCORBA::Priority original_CORBA_priority_;
+ // Original priority of the thread.
+ RTCORBA::Priority original_priority_;
};
#include "ace/post.h"